@@ -37,9 +37,8 @@ oneTimeSetUp() {
 
     # check in OpenSSL supports dane checks
     if openssl s_client -help 2>&1 | grep -q -- -dane_tlsa_rrdata || openssl s_client not_a_real_option 2>&1 | grep -q -- -dane_tlsa_rrdata; then
-
-    echo "dane checks supported"
-    DANE=1
+        echo "dane checks supported"
+        DANE=1
     fi
 
 }
@@ -156,6 +155,18 @@ testMissingArgument2() {
     assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
 }
 
+testGroupedVariables() {
+    ${SCRIPT} --rootcert-file cabundle.crt -H www.google.com -vvv > /dev/null 2>&1
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+}
+
+testGroupedVariablesError() {
+    ${SCRIPT} --rootcert-file cabundle.crt -H www.google.com -vvxv > /dev/null 2>&1
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
+}
+
 testETHZ() {
     ${SCRIPT} --rootcert-file cabundle.crt -H ethz.ch --cn ethz.ch
     EXIT_CODE=$?
@@ -175,20 +186,23 @@ testGoDaddy() {
 }
 
 testETHZCaseInsensitive() {
-    # debugging: to be removed
     ${SCRIPT} --rootcert-file cabundle.crt -H ethz.ch --cn ETHZ.CH
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testETHZWildCard() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H sherlock.sp.ethz.ch --cn sp.ethz.ch
+    # * should not match, see https://serverfault.com/questions/310530/should-a-wildcard-ssl-certificate-secure-both-the-root-domain-as-well-as-the-sub
+    # we ignore the altnames as sp.ethz.ch is listed
+    ${SCRIPT} --rootcert-file cabundle.crt -H sherlock.sp.ethz.ch --cn sp.ethz.ch --ignore-altnames
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testETHZWildCardCaseInsensitive() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H sherlock.sp.ethz.ch --cn SP.ETHZ.CH
+    # * should not match, see https://serverfault.com/questions/310530/should-a-wildcard-ssl-certificate-secure-both-the-root-domain-as-well-as-the-sub
+    # we ignore the altnames as sp.ethz.ch is listed
+    ${SCRIPT} --rootcert-file cabundle.crt -H sherlock.sp.ethz.ch --cn SP.ETHZ.CH --ignore-altnames
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
@@ -232,7 +246,7 @@ testAltNames() {
 
 #Do not require to match Alternative Name if CN already matched
 testWildcardAltNames1() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H sherlock.sp.ethz.ch --altnames --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H sherlock.sp.ethz.ch --altnames
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
@@ -270,18 +284,12 @@ testMultipleAltNamesFailTwo() {
 }
 
 testXMPPHost() {
-    # $TRAVIS is set an environment variable
-    # shellcheck disable=SC2154
-    if [ -z "${TRAVIS+x}" ] ; then
-        out=$(${SCRIPT} --rootcert-file cabundle.crt -H prosody.xmpp.is --port 5222 --protocol xmpp --xmpphost xmpp.is )
-        EXIT_CODE=$?
-        if echo "${out}" | grep -q "s_client' does not support '-xmpphost'" ; then
-            assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
-        else
-            assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-        fi
+    out=$(${SCRIPT} --rootcert-file cabundle.crt -H prosody.xmpp.is --port 5222 --protocol xmpp --xmpphost xmpp.is )
+    EXIT_CODE=$?
+    if echo "${out}" | grep -q "s_client' does not support '-xmpphost'" ; then
+        assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
     else
-        echo "Skipping XMPP tests on Travis CI"
+        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
     fi
 }
 
@@ -292,55 +300,35 @@ testTimeOut() {
 }
 
 testIMAP() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        # minimal critical and warning as they renew pretty late
-        ${SCRIPT} --rootcert-file cabundle.crt -H imap.gmx.com --port 143 --timeout 30 --protocol imap --critical 1 --warning 2
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping IMAP tests on Travis CI"
-    fi
+    # minimal critical and warning as they renew pretty late
+    ${SCRIPT} --rootcert-file cabundle.crt -H imap.gmx.com --port 143 --timeout 30 --protocol imap --critical 1 --warning 2
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testIMAPS() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H imap.gmail.com --port 993 --timeout 30 --protocol imaps
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping IMAP tests on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H imap.gmail.com --port 993 --timeout 30 --protocol imaps
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testPOP3S() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H pop.gmail.com --port 995 --timeout 30 --protocol pop3s
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping POP3S tests on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H pop.gmail.com --port 995 --timeout 30 --protocol pop3s
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 
 testSMTP() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H smtp.gmail.com --protocol smtp --port 25 --timeout 60
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping SMTP tests on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H smtp.gmail.com --protocol smtp --port 25 --timeout 60
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testSMTPSubmbission() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H smtp.gmail.com --protocol smtp --port 587 --timeout 60
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping SMTP tests on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H smtp.gmail.com --protocol smtp --port 587 --timeout 60
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testSMTPS() {
@@ -366,175 +354,154 @@ testSMTPS() {
 # From https://badssl.com
 
 testBadSSLExpired() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H expired.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H expired.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLExpiredAndWarnThreshold() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H expired.badssl.com --host-cn --warning 3000
+    ${SCRIPT} --rootcert-file cabundle.crt -H expired.badssl.com --warning 3000
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLWrongHost() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H wrong.host.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H wrong.host.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLSelfSigned() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H self-signed.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H self-signed.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLUntrustedRoot() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H untrusted-root.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H untrusted-root.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLRevoked() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H revoked.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H revoked.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLRevokedCRL() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H revoked.badssl.com --host-cn --crl --ignore-ocsp
+    ${SCRIPT} --rootcert-file cabundle.crt -H revoked.badssl.com --crl --ignore-ocsp
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testGRCRevoked() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H revoked.grc.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H revoked.grc.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLIncompleteChain() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H incomplete-chain.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H incomplete-chain.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLDH480(){
-    ${SCRIPT} --rootcert-file cabundle.crt -H dh480.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H dh480.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLDH512(){
-    ${SCRIPT} --rootcert-file cabundle.crt -H dh512.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H dh512.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLRC4MD5(){
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H rc4-md5.badssl.com --host-cn
+    # older versions of OpenSSL validate RC4-MD5
+    if ! openssl ciphers RC4-MD5 > /dev/null 2>&1 ; then
+        ${SCRIPT} --rootcert-file cabundle.crt -H rc4-md5.badssl.com
         EXIT_CODE=$?
         assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
     else
-        echo "Skipping RC4 MD5 with badssl.com on Travis CI (OpenSSL too old)"
+        echo "OpenSSL too old to test RC4-MD5 ciphers"
     fi
 }
 
 testBadSSLRC4(){
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H rc4.badssl.com --host-cn
+    # older versions of OpenSSL validate RC4
+    if ! openssl ciphers RC4 > /dev/null 2>&1 ; then
+        ${SCRIPT} --rootcert-file cabundle.crt -H rc4.badssl.com
         EXIT_CODE=$?
         assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
     else
-        echo "Skipping RC4 with badssl.com on Travis CI (OpenSSL too old)"
+        echo "OpenSSL too old to test RC4-MD5 ciphers"
     fi
 }
 
 testBadSSL3DES(){
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H 3des.badssl.com --host-cn
+    # older versions of OpenSSL validate RC4
+    if ! openssl ciphers 3DES > /dev/null 2>&1 ; then
+        ${SCRIPT} --rootcert-file cabundle.crt -H 3des.badssl.com
         EXIT_CODE=$?
         assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
-    else
-        echo "Skipping 3DES with badssl.com on Travis CI (OpenSSL too old)"
+      else
+        echo "OpenSSL too old to test 3DES ciphers"
     fi
 }
 
 testBadSSLNULL(){
-    ${SCRIPT} --rootcert-file cabundle.crt -H null.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H null.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLSHA256() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H sha256.badssl.com --host-cn
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping SHA 256 with badssl.com on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H sha256.badssl.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testBadSSLEcc256() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H ecc256.badssl.com --host-cn
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping ECC 256 with badssl.com on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H ecc256.badssl.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testBadSSLEcc384() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H ecc384.badssl.com --host-cn
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping ECC 384 with badssl.com on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H ecc384.badssl.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testBadSSLRSA8192() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H rsa8192.badssl.com --host-cn
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping RSA8192 with badssl.com on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H rsa8192.badssl.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testBadSSLLongSubdomainWithDashes() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H long-extended-subdomain-name-containing-many-letters-and-dashes.badssl.com --host-cn
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping long subdomain with dashes with badssl.com on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H long-extended-subdomain-name-containing-many-letters-and-dashes.badssl.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testBadSSLLongSubdomain() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H longextendedsubdomainnamewithoutdashesinordertotestwordwrapping.badssl.com --host-cn
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping long subdomain with badssl.com on Travis CI"
-    fi
+    ${SCRIPT} --rootcert-file cabundle.crt -H longextendedsubdomainnamewithoutdashesinordertotestwordwrapping.badssl.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
 testBadSSLSHA12016() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H sha1-2016.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H sha1-2016.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
 testBadSSLSHA12017() {
-    ${SCRIPT} --rootcert-file cabundle.crt -H sha1-2017.badssl.com --host-cn
+    ${SCRIPT} --rootcert-file cabundle.crt -H sha1-2017.badssl.com
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
@@ -565,7 +532,16 @@ testIPv4() {
 testIPv6() {
     if openssl s_client -help 2>&1 | grep -q -- -6 ; then
 
-        if ifconfig -a | grep -q inet6 ; then
+	IPV6=
+	if command -v ifconfig > /dev/null && ifconfig -a | grep -q -F inet6 ; then
+	    IPV6=1
+	elif command -v ip > /dev/null && ip addr | grep -q -F inet6 ; then
+	    IPV6=1
+	fi
+
+        if [ -n "${IPV6}" ] ; then
+
+	    echo "IPv6 is configured"
 
             if ping -6 www.google.com > /dev/null 2>&1  ; then
 
@@ -612,18 +588,29 @@ testMoreErrors2() {
 # dane
 
 testDANE211() {
-    # $TRAVIS is set an environment variable
-    # shellcheck disable=SC2154
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt --dane 211  --port 25 -P smtp -H hummus.csx.cam.ac.uk
-        EXIT_CODE=$?
-        if [ -n "${DANE}" ] ; then
-            assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+    # dig is needed for DANE
+    if command -v dig > /dev/null ; then
+
+        # on github actions the dig command produces no output
+        if dig +short TLSA _25._tcp.hummus.csx.cam.ac.uk | grep -q -f 'hummus' ; then
+
+            # check if a connection is possible
+            if printf 'QUIT\\n' | openssl s_client -connect hummus.csx.cam.ac.uk:25 -starttls smtp > /dev/null 2>&1 ; then
+                ${SCRIPT} --rootcert-file cabundle.crt --dane 211  --port 25 -P smtp -H hummus.csx.cam.ac.uk
+                EXIT_CODE=$?
+                if [ -n "${DANE}" ] ; then
+                    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+                else
+                    assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
+                fi
+            else
+                echo "connection to hummus.csx.cam.ac.uk:25 not possible: skipping test"
+            fi
         else
-            assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
+            echo "no TLSA entries in DNS: skipping DANE test"
         fi
     else
-        echo "Skipping SMTP tests on Travis CI"
+        echo "dig not available: skipping DANE test"
     fi
 }
 
@@ -649,12 +636,16 @@ testDANE211() {
 #}
 
 testDANE301ECDSA() {
-    ${SCRIPT} --rootcert-file cabundle.crt --dane 301 --ecdsa -H mail.aegee.org
-    EXIT_CODE=$?
-    if [ -n "${DANE}" ] ; then
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+    if command -v dig > /dev/null ; then
+        ${SCRIPT} --rootcert-file cabundle.crt --dane 301 --ecdsa -H mail.aegee.org
+        EXIT_CODE=$?
+        if [ -n "${DANE}" ] ; then
+            assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+        else
+            assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
+        fi
     else
-        assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
+        echo "dig not available: skipping DANE test"
     fi
 }
 
@@ -670,16 +661,6 @@ testRequiredProgramPermissions() {
     assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
 }
 
-testSieveRSA() {
-    if ! { openssl s_client -starttls sieve 2>&1 | grep -F -q 'Value must be one of:' || openssl s_client -starttls sieve 2>&1 | grep -F -q 'usage:' ; } ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -P sieve -p 4190 -H mail.aegee.org --rsa
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
-    else
-        echo "Skipping sieve tests (not supported)"
-    fi
-}
-
 testSieveECDSA() {
     if ! { openssl s_client -starttls sieve 2>&1 | grep -F -q 'Value must be one of:' || openssl s_client -starttls sieve 2>&1 | grep -F -q 'usage:' ; } ; then
         ${SCRIPT} --rootcert-file cabundle.crt -P sieve -p 4190 -H mail.aegee.org --ecdsa
@@ -737,24 +718,86 @@ testCertificsteWithEmptySubject() {
     assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
 
+testResolveSameName() {
+    ${SCRIPT} --rootcert-file cabundle.crt -H corti.li --resolve corti.li
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+}
+
+testResolveDifferentName() {
+    ${SCRIPT} --rootcert-file cabundle.crt -H corti.li --resolve www.google.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+}
+
+testResolveCorrectIP() {
+    ${SCRIPT} --rootcert-file cabundle.crt -H corti.li --resolve "$( dig +short corti.li )"
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+}
+
+testResolveWrongIP() {
+    ${SCRIPT} --rootcert-file cabundle.crt -H corti.li --resolve "$( dig +short www.google.com )"
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+}
+
 testCiphersOK() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H www.wikipedia.org --check-ciphers A --check-ciphers-warnings
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+
+    # nmap ssl-enum-ciphers dumps core on CentOS 7 and RHEL 7
+    if [ -f /etc/redhat-release ] && grep -q '.*Linux.*release\ 7\.' /etc/redhat-release ; then
+        echo 'Skipping tests on CentOS and RedHat 7 since nmap is crashing (core dump)'
     else
-        echo "Skipping nmap cipher warnings tests as nmap is too old"
+
+        # check if nmap is installed
+        if command -v nmap > /dev/null ; then
+
+            # check if ssl-enum-ciphers is present
+            if ! nmap --script ssl-enum-ciphers 2>&1 | grep -q -F 'NSE: failed to initialize the script engine' ; then
+
+                ${SCRIPT} --rootcert-file cabundle.crt -H cloudflare.com --check-ciphers C
+                EXIT_CODE=$?
+                assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+
+            else
+                echo "no ssl-enum-ciphers nmap script found: skipping ciphers test"
+            fi
+
+        else
+            echo "no nmap found: skipping ciphers test"
+        fi
+
     fi
+
 }
 
 testCiphersError() {
-    if [ -z "${TRAVIS+x}" ] ; then
-        ${SCRIPT} --rootcert-file cabundle.crt -H ethz.ch --check-ciphers A --check-ciphers-warnings
-        EXIT_CODE=$?
-        assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+
+    # nmap ssl-enum-ciphers dumps core on CentOS 7 and RHEL 7
+    if [ -f /etc/redhat-release ] && grep -q '.*Linux.*release\ 7\.' /etc/redhat-release ; then
+        echo 'Skipping tests on CentOS and RedHat 7 since nmap is crashing (core dump)'
     else
-        echo "Skipping nmap cipher warnings tests as nmap is too old"
+
+        # check if nmap is installed
+        if command -v nmap > /dev/null ; then
+
+            # check if ssl-enum-ciphers is present
+            if ! nmap --script ssl-enum-ciphers 2>&1 | grep -q -F 'NSE: failed to initialize the script engine' ; then
+
+                ${SCRIPT} --rootcert-file cabundle.crt -H ethz.ch --check-ciphers A --check-ciphers-warnings
+                EXIT_CODE=$?
+                assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+
+            else
+                echo "no ssl-enum-ciphers nmap script found: skipping ciphers test"
+            fi
+
+        else
+            echo "no nmap found: skipping ciphers test"
+        fi
+
     fi
+
 }
 
 # SSL Labs (last one as it usually takes a lot of time
